<?xml version="1.0"?>

<!--
Copyright 2001 DAX Interactive, LLC.

$Author: jonathan $
$Revision: 1.1.1.1 $
$Header: /home/cvspublic/opendj/opendj-docs/protocols/protocol2html.xsl,v 1.1.1.1 2001/09/29 20:31:57 jonathan Exp $
$Log: protocol2html.xsl,v $
Revision 1.1.1.1  2001/09/29 20:31:57  jonathan
Imported opendj-docs

-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="1.0">

<xsl:template match="protocol-spec">
  <html>
    <head>
      <title><xsl:value-of select="name" /></title>
      <link rel="stylesheet" type="text/css" href="/include/protocol.css" />
    </head>
    <body bgcolor="#000000">
      <a name="top" />
      <xsl:apply-templates select="*" />
      <font class="protocolspec">
        END <xsl:value-of select="name" />
      </font>
      <font class="header2">
        <a href="#top">[back to top]</a>
      </font>
    </body>
  </html>
</xsl:template>

<xsl:template match="name">

  <xsl:choose>

    <xsl:when test="local-name(..)='protocol-spec'">
      <font class="protocolspec">
        <xsl:value-of select="text()" />
      </font>
      <br />
      <hr />
    </xsl:when>
<!--
    <xsl:when test="local-name(..)='message'">
      <font class="message"><xsl:value-of select="name" /></font><br />
    </xsl:when>
-->
  </xsl:choose>

</xsl:template>

<xsl:template match="version">
  <font class="version">
   Version: <xsl:value-of select="text()" />
  </font>
  <br />
</xsl:template>

<xsl:template match="author">
  <font class="author">
    By: <xsl:value-of select="text()" />
  </font>
  <br />
</xsl:template>

<xsl:template match="copyright">
  <font class="description">
    <xsl:value-of select="text()" />
  </font>
  <br />
  <hr />
</xsl:template>

<xsl:template match="revisions">
  <table border="0">

    <tr>
     <th>
      <font class="revisions">Revision History</font>
     </th>
    </tr>

    <xsl:apply-templates select="*" />

  </table>

  <hr />
</xsl:template>

<xsl:template match="revision">
  <tr>
   <xsl:apply-templates select="*" />
  </tr>
</xsl:template>

<xsl:template match="date">
  <td><font class="date"><xsl:value-of select="text()" /> - </font></td>
</xsl:template>

<xsl:template match="comments">
  <td><font class="comments"><xsl:value-of select="text()" /></font></td>
</xsl:template>

<xsl:template match="description">

  <xsl:if test="local-name(..)='protocol-spec'">
    <font class="header1">
      CONTENTS:<br />
    </font>
    <font class="header2">
    <a href="#overview">Overview</a> | 
    <a href="#usage">Protocol Usage</a> | 
    <a href="#states">Protocol States</a> | 
    <a href="#messages">Protocol Messages</a>
    </font>
    <hr />
    <a name="overview" />
    <font class="chapter">
      OVERVIEW
    </font>
    <br />
  </xsl:if>

  <xsl:if test="count(./paragraph)=0">
    <p class="description">
      <xsl:value-of select=".//text()" />
    </p>
  </xsl:if>

  <xsl:if test="count(./paragraph)>0">
    <xsl:apply-templates select="*" />
  </xsl:if>

</xsl:template>

<xsl:template match="paragraph">
  <p class="description">
    <xsl:value-of select=".//text()" />

  <!-- This is really ugly, just to get the format-line elements
       inside the initial description to work - note that this
       only works because the format-line elements are at the end -->
    <xsl:apply-templates select="*" />
  </p>
</xsl:template>

<xsl:template match="usage">
  <hr />
  <a name="usage" />
  <font class="chapter">
    PROTOCOL USAGE
  </font>
  <br />
  <xsl:apply-templates select="*" />
</xsl:template>

<xsl:template match="states">

  <hr />
  <a name="states" />
  <font class="chapter">
    PROTOCOL STATES
  </font>

  <table border="1">
    <tr>
      <th><font class="states_th">State</font></th>
      <th><font class="states_th">Description</font></th>
    </tr>

    <xsl:apply-templates select="*" />

  </table>

</xsl:template>

<xsl:template match="state">

  <xsl:choose>

    <xsl:when test="local-name(..)='states'">
      <tr>
        <td><font class="state_name"><xsl:value-of select="@name" /></font></td>
        <td><font class="state_desc"><xsl:apply-templates select="*" /></font></td>
      </tr>
    </xsl:when>

    <xsl:when test="local-name(..)='valid-states'">
      <xsl:value-of select="@name" />
    </xsl:when>

  </xsl:choose>

</xsl:template>

<xsl:template match="messages">

  <hr />
  <a name="messages" />
  <font class="chapter">
    PROTOCOL MESSAGES
  </font>

  <br />

  <xsl:if test="count(.//message[attribute::source='client'])>0">
    <font class="header2">
      Client -&gt; Server Messages

      <xsl:for-each select=".//message[attribute::source='client']">
        |
        <xsl:element name="a">
          <xsl:attribute name="class">message_link</xsl:attribute>
          <xsl:attribute name="href">#<xsl:value-of select="name" /></xsl:attribute>
          <xsl:value-of select="./name" />
        </xsl:element>
      </xsl:for-each>

    </font><br />
  </xsl:if>

  <xsl:if test="count(.//message[attribute::source='server'])>0">
    <font class="header2">
      Server -&gt; Client Messages

      <xsl:for-each select=".//message[attribute::source='server']">
        |
        <xsl:element name="a">
          <xsl:attribute name="class">message_link</xsl:attribute>
          <xsl:attribute name="href">#<xsl:value-of select="name" /></xsl:attribute>
          <xsl:value-of select="./name" />
        </xsl:element>
      </xsl:for-each>

    </font><br />
  </xsl:if>

  <hr />

  <xsl:apply-templates select="*" />

</xsl:template>

<xsl:template match="message">
  <a name="{name}" />
  <table border="1">

  <tr>
    <td>
      <font class="message">
        <xsl:value-of select="name" /> Message
        (from <xsl:value-of select="@source" /> 
         to <xsl:value-of select="@destination" />):
      </font>
    </td>
  </tr>
  <tr>
    <td>
      <xsl:apply-templates select="./request/valid-states" />
      <br />

      <xsl:apply-templates select="./request/format" />
      <br />

      <xsl:apply-templates select="./request/example" />

      <xsl:apply-templates select="./request/description/*" />
      <br />

      <xsl:if test="count(./responses)>0">
        <font class="header1">RESPONSES:</font><br /><br />
        <xsl:apply-templates select="./responses/*" />
      </xsl:if>
    </td>
  </tr>

  </table>

  <hr />

</xsl:template>

<xsl:template match="request" />

<xsl:template match="valid-states">
  <font class="validstates">
    May be legally issued from these states:
  </font>
  <font class="validstate">
    <xsl:apply-templates select="*" />
  </font>
  <br />
</xsl:template>

<xsl:template match="format">
<font class="header3">

  FORMAT: 

  <code>

    <xsl:if test="count(./format-line)>0">
      <xsl:apply-templates select="format-line" />
    </xsl:if>

    <xsl:if test="count(./format-line)=0">
      <xsl:value-of select="text()" />
    </xsl:if>

  </code>

</font>
</xsl:template>

<xsl:template match="example">
<font class="header3">
  EXAMPLE: <code><xsl:value-of select="text()" /></code>
</font>
</xsl:template>

<xsl:template match="responses" />

<xsl:template match="response">
  <font class="header1">
    <xsl:value-of select="./name" /> Response
  </font><br />
  <xsl:apply-templates select="*" />
  <br />
</xsl:template>

<xsl:template match="result-state">
  <font class="header2">
  Result State: <xsl:value-of select="@name" /> <br />
  </font>
</xsl:template>

<xsl:template match="format-line">
  <xsl:value-of select="text()" /><br />
</xsl:template>

</xsl:stylesheet>
